Hier sind häufige Probleme und mögliche Lösungen:

## Mail kommt in einer Schleife zu sich selbst zurück.

Bitte überprüfen Sie in Ihrer mailcow UI, ob Sie die Domain als **Backup MX** eingestellt haben:
![Überprüfen Sie Ihre MX-Backup-Einstellungen](../assets/images/troubleshooting/mailcow-backupmx.png)

## Ich kann Mails empfangen, aber nicht senden

Es gibt viele Gründe, die Sie daran hindern können, Mails zu versenden:

- Prüfen Sie, ob Ihre IP-Adresse auf einer schwarzen Liste steht. Sie können [dnsbl.info](http://www.dnsbl.info/) oder einen ähnlichen Dienst verwenden, um Ihre IP-Adresse zu überprüfen.
- Es gibt einige ISP-Router, die Mail-Ports für nicht auf der Blacklist stehende Domains blockieren. Bitte überprüfen Sie, ob Sie Ihren Server über die Ports `465` oder `587` erreichen können:

```
# telnet 74.125.133.27 465
Versucht 74.125.133.27...
Verbunden mit 74.125.133.27.
Escape-Zeichen ist '^]'.
```

## Meine Mails werden als Spam identifiziert

Bitte lesen Sie unsere [DNS-Konfiguration](../getstarted/prerequisite-dns.de.md) Anleitung.

## docker compose wirft seltsame Fehler aus.

... wie:

- `ERROR: Ungültiges Interpolationsformat ...`
- `AttributeError: 'NoneType' Objekt hat kein Attribut 'keys'`.
- ERROR: In der Datei './docker-compose.yml' hat der Dienst 'version' keine Konfigurationsoptionen.

Wenn Sie eine oder ähnliche Meldungen erhalten, während Sie versuchen, mailcow: dockerized auszuführen, überprüfen Sie bitte, ob Sie die **aktuellste** Version von **Docker** und **docker compose** haben.

## Container XY ist ungesund

Dieser Fehler versucht Ihnen mitzuteilen, dass eine der (Gesundheits-)Bedingungen für einen bestimmten Container nicht erfüllt ist. Daher kann er nicht gestartet werden. Dies kann verschiedene Gründe haben, der häufigste ist ein aktualisierter Git-Klon, aber ein altes Docker-Image oder umgekehrt.

Auch eine falsch konfigurierte Firewall kann einen solchen Fehler verursachen. Die Container müssen in der Lage sein, über das Netzwerk 172.22.1.1/24 miteinander zu kommunizieren.

Es könnte auch eine falsch verknüpfte Datei sein (z. B. ein SSL-Zertifikat), die den Start eines wichtigen Containers (nginx) verhindert. Prüfen Sie daher immer Ihre Protokolle, um herauszufinden, woher das Problem kommt.


## Adresse bereits in Gebrauch

Wenn Sie eine Fehlermeldung erhalten wie:

```
ERROR: for postfix-mailcow Cannot start service postfix-mailcow: driver failed programming external connectivity on endpoint mailcowdockerized_postfix-mailcow_1: Error starting userland proxy: listen tcp 0.0.0:25: bind: address already in use
```

während Sie versuchen, mailcow: dockerized zu starten / zu installieren, stellen Sie sicher, dass Sie unseren Abschnitt über [prerequisites](../getstarted/prerequisite-system.de.md/#firewall-ports) befolgt haben.


## XYZ kann keine Verbindung zu ...

Bitte überprüfen Sie Ihre lokale Firewall!
Docker und iptables-basierte Firewalls erstellen manchmal widersprüchliche Regeln. Deaktivieren Sie daher die Firewall auf Ihrem Host, um festzustellen, ob Ihre Verbindungsprobleme durch solche Konflikte verursacht werden. Wenn dies der Fall ist, müssen Sie manuell entsprechende Regeln in Ihrer Host-Firewall erstellen, um die erforderlichen Verbindungen zuzulassen.

Wenn Sie Verbindungsprobleme von zu Hause aus haben, überprüfen Sie bitte auch die Firewall Ihres ISP-Routers, da einige von ihnen den E-Mail-Verkehr über die Ports *SMTP* (587) oder *SMTPS* (465) blockieren. Es könnte auch sein, dass Ihr ISP die Ports für *SUBMISSION* (25) blockiert.

Während Linux-Benutzer aus einer Vielzahl von Tools[^1] wählen können, um zu überprüfen, ob ein Port offen ist, steht Windows-Benutzern standardmäßig nur der PowerShell-Befehl `Test-NetConnection -ComputerName host -Port port` zur Verfügung.

Um Telnet auf einem Windows nach Vista zu aktivieren, lesen Sie bitte diese [Anleitung](https://social.technet.microsoft.com/wiki/contents/articles/910.windows-7-enabling-telnet-client.aspx) oder geben Sie den folgenden Befehl in einem Terminal **mit Administratorrechten** ein:

```
dism /online /Enable-Feature /FeatureName:TelnetClient
```

## Inotify-Instanz-Limit überschritten für Benutzer 5000 (UID vmail) ([siehe #453](https://github.com/mailcow/mailcow-dockerized/issues/453#issuecomment-314711232)).

Docker-Container verwenden die inotify-Limits von Docker-Hosts. Wenn Sie sie auf Ihrem Docker-Host setzen, werden sie an den Container weitergegeben.

## Dovecot startet ständig neu (siehe [#2672](https://github.com/mailcow/mailcow-dockerized/issues/2672)).

Stellen Sie sicher, dass Sie mindestens die folgenden Dateien in `data/assets/ssl` haben:

```
cert.pem
dhparams.pem
key.pem
```

Wenn `dhparams.pem` fehlt, können Sie es mit Bash

```bash
openssl dhparam -out data/assets/ssl/dhparams.pem 4096
```

## Rspamd meldet: cannot open hyperscan cache file /var/lib/rspamd/{...}.hs: compiled for a different platform

Bei einer Migration von mailcow auf ein anderes System (meistens mit einer anderen CPU) kann es unter Umständen passieren, dass Rspamd meldet er könne einige (evtl. alle) `.hs` Dateien nicht laden, da diese für eine andere Plattform (CPU) kompiliert wurden.

Dies hängt mit Hyperscan[^2] zusammen einer Intel Technik zum vorkompilieren von regex Schemata, welche Rspamd einsetzt.

Diese Funktion bringt einen erheblichen Performance Boost mit sich und ist deswegen stark in Rspamd verankert.

Um diesen Fehler zu beheben, müssen alle `.hs` und `.hsmp` Dateien aus dem Rspamd Verzeichnis gelöscht werden:

=== "docker compose (Plugin)"

    ``` bash
    cd MAILCOW_ROOT # Meistens /opt/mailcow-dockerized
    docker compose exec rspamd-mailcow bash
    rm -rf /var/lib/rspamd/*.hs
    rm -rf /var/lib/rspamd/*.hsmp
    ```

=== "docker-compose (Standalone)"

    ``` bash
    cd MAILCOW_ROOT # Meistens /opt/mailcow-dockerized
    docker-compose exec rspamd-mailcow bash
    rm -rf /var/lib/rspamd/*.hs
    rm -rf /var/lib/rspamd/*.hsmp
    ```

Anschließend Rspamd neustarten mit:

=== "docker compose (Plugin)"

    ``` bash
    docker compose restart rspamd-mailcow
    ```

=== "docker-compose (Standalone)"

    ``` bash
    docker-compose restart rspamd-mailcow
    ```

Nun kompiliert Rspamd die besagten Regex Maps wieder neu mit Hyperscan.


[^1]: [netcat](https://linux.die.net/man/1/nc), [nmap](https://linux.die.net/man/1/nmap), [openssl](https://wiki.openssl.org/index.php/Manual:S_client(1)), [telnet](https://linux.die.net/man/1/telnet), etc.
[^2]: [Hyperscan](https://github.com/intel/hyperscan)
